symbols

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package symbols provides source code symbol extraction and skeleton generation.

Package symbols provides source code symbol extraction across supported languages.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractSymbols

func ExtractSymbols(relPath string, language string, content []byte) ([]db.SymbolRecord, error)

ExtractSymbols parses source code based on its language and returns declared symbols.

func GenerateSkeleton

func GenerateSkeleton(relPath string, language string, content []byte, syms []db.SymbolRecord) string

GenerateSkeleton returns a token-efficient structural outline of a source file with stripped function bodies.

Types

This section is empty.

Jump to