Documentation
¶
Overview ¶
Package symbols provides source code symbol extraction and skeleton generation.
Package symbols provides source code symbol extraction across supported languages.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExtractSymbols ¶
ExtractSymbols parses source code based on its language and returns declared symbols.
func GenerateSkeleton ¶
func GenerateSkeleton(relPath string, language string, content []byte, syms []db.SymbolRecord) string
GenerateSkeleton returns a token-efficient structural outline of a source file with stripped function bodies.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.